@@ -11,4 +11,7 @@ test_that("Simple logging",{
   # crash test: does multi-piping work under NSE?
   i2 <- head(women) %>>% start_log() %>>% identity() %>>% dump_log(file=logfile)
   expect_true(file.exists(logfile))
+  logger <- simple$new()
+  iris %>>% start_log(logger) %>>% head() %>>% stop_log()
+  expect_equal(nrow(logger$logdata()), 2)
 })
